﻿using Microsoft.Win32;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UselessApp
{
    public partial class MainForm : Form
    {
        private Profile _profile;
        public Profile Profile
        {
            get
            {
                return _profile;
            }
            private set
            {
                _profile = value;

                SetTemplate(_profile.Gender);
                if (_profile.Picture != null)
                {
                    profilePicture = Image.FromFile(_profile.Picture);
                }

                currentToolStripMenuItem.Text = _profile.Name;
                currentToolStripMenuItem.Visible = true;

                greetingLabel.Text = String.Format("Hello {0}!", _profile.Name);
                greetingLabel.Visible = _profile.Greeting;
            }
        }

        private Image profilePicture;

        public MainForm()
        {
            InitializeComponent();

            //Praca s registrami - pri spusteni sa program pozrie ci ma v registroch ulozeny vychodzi profil
            RegistryKey myReg = Registry.CurrentUser.OpenSubKey(@"Software", RegistryKeyPermissionCheck.ReadWriteSubTree)
                .CreateSubKey("UselessApp", RegistryKeyPermissionCheck.ReadWriteSubTree);

            string lastProfile = myReg.GetValue("Profile") as string;

            if ((lastProfile != null) && (new FileInfo(lastProfile)).Exists)
            {
                Profile = LoadProfile(lastProfile);
            }
        }

        protected override void OnClosing(CancelEventArgs e)
        {
            base.OnClosing(e);

            //Praca s registrami - pri ukonceni si program ulozi aktivny profil do registrov
            if (Profile.File != null)
            {
                RegistryKey myReg = Registry.CurrentUser.OpenSubKey(@"Software", RegistryKeyPermissionCheck.ReadWriteSubTree)
                    .CreateSubKey("UselessApp", RegistryKeyPermissionCheck.ReadWriteSubTree);

                myReg.SetValue("Profile", Profile.File);

                myReg.Close();
            }
        }

        protected override void OnPaint(PaintEventArgs e)
        {
            base.OnPaint(e);

            if (profilePicture != null)
            {
                e.Graphics.DrawImage(profilePicture, new Rectangle(400, 200, 120, 120));
            }
        }

        private void quitToolStripMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void changeToolStripMenuItem_Click(object sender, EventArgs e)
        {
            OpenFileDialog diag = new OpenFileDialog();

            diag.Title = "Select Profile";
            diag.Filter = "Universal App Profile (*.uap)|*.uap";

            if (diag.ShowDialog() == DialogResult.OK)
            {
                Profile = LoadProfile(diag.FileName);
            }
        }

        private void SetTemplate(Gender gender)
        {
            switch (gender)
            {
                case Gender.Boy:
                    {
                        profilePicture = Image.FromFile("smiley_cyan.png");

                        greetingLabel.Font = new Font("Centaur", 24);
                        greetingLabel.ForeColor = Color.DarkBlue;

                        BackColor = Color.LightCyan;

                        break;
                    }
                case Gender.Girl:
                    {
                        profilePicture = Image.FromFile("smiley_pink.png");

                        greetingLabel.Font = new Font("Tempus Sans ITC", 20);
                        greetingLabel.ForeColor = Color.Crimson;

                        BackColor = Color.LightPink;

                        break;
                    }
                default:
                    {
                        break;
                    }
            }
        }

        private Profile LoadProfile(string fileName)
        {
            IDictionary<string, string> values = new Dictionary<string, string>();

            using (StreamReader sr = new StreamReader(fileName))
            {
                string line;
                while ((line = sr.ReadLine()) != null)
                {
                    string[] data = line.Split('=');
                    values.Add(data[0], data[1]);
                }
            }

            return new Profile()
            {
                Name = values["name"],
                File = fileName,
                Gender = (Gender)Enum.Parse(typeof(Gender), values["gender"]),
                Greeting = Boolean.Parse(values["greeting"]),
                Picture = (values.ContainsKey("picture") ? values["picture"] : null)
            };
        }

        private void newToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ProfileDialog diag = new ProfileDialog();

            if (diag.ShowDialog() == DialogResult.OK)
            {
                Profile = diag.Profile;
            }
        }

        private void currentToolStripMenuItem_Click(object sender, EventArgs e)
        {
            ProfileDialog diag = new ProfileDialog(Profile);

            if (diag.ShowDialog() == DialogResult.OK)
            {
                Profile = diag.Profile;
            }
        }
    }
}
