﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;

namespace UselessApp
{
    public partial class ProfileDialog : Form
    {
        public Profile Profile { get; private set; }

        public ProfileDialog()
        {
            InitializeComponent();
        }

        public ProfileDialog(Profile profile)
            : this()
        {
            Text = profile.Name;
            nameTextBox.Text = profile.Name;

            switch (profile.Gender)
            {
                case Gender.Boy:
                    {
                        boyRadioButton.Checked = true;
                        break;
                    }
                case Gender.Girl:
                    {
                        girlRadioButton.Checked = true;
                        break;
                    }
                default: break;
            }

            greetingCheckBox.Checked = profile.Greeting;

            if (profile.Picture != null)
            {
                pictureCheckBox.Checked = true;
                pictureTextBox.Text = profile.Picture;
            }
        }

        private void pictureCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            pictureTextBox.Enabled = pictureCheckBox.Checked;
            browseButton.Enabled = pictureCheckBox.Checked;
        }

        private void browseButton_Click(object sender, EventArgs e)
        {
            OpenFileDialog diag = new OpenFileDialog();

            diag.Title = "Choose Picture to use";
            diag.Filter = "Image Files (*.png,*.jpg,*.bmp)|*.jpg;*.png;*.bmp";
            
            if (diag.ShowDialog() == DialogResult.OK)
            {
                pictureTextBox.Text = diag.FileName;
            }
        }

        private void cancelButton_Click(object sender, EventArgs e)
        {
            DialogResult = DialogResult.Cancel;
            Close();
        }

        private void SaveProfile()
        {
            using (StreamWriter sw = new StreamWriter(Profile.File))
            {
                sw.WriteLine("name={0}", Profile.Name);
                sw.WriteLine("gender={0}", Profile.Gender);
                sw.WriteLine("greeting={0}", Profile.Greeting);
                if (Profile.Picture != null)
                {
                    sw.WriteLine("picture={0}", Profile.Picture);
                }
            }
        }

        private void okButton_Click(object sender, EventArgs e)
        {
            if (!ValidateChildren())
            {
                return;
            }

            if ((boyRadioButton.Checked == false) && (girlRadioButton.Checked == false))
            {
                errorProvider.SetError(genderLabel, "You must pick your gender.");
                return;
            }
            else
            {
                errorProvider.SetError(genderLabel, null);
            }

            SaveFileDialog diag = new SaveFileDialog();

            diag.Title = "Save Profile";
            diag.Filter = "Universal App Profile (*.uap)|*.uap";
            diag.DefaultExt = ".uap";
            diag.AddExtension = true;
            diag.FileName = String.Format("{0}.uap", nameTextBox.Text);
            diag.InitialDirectory = Environment.CurrentDirectory;

            if (diag.ShowDialog() == DialogResult.OK)
            {
                Profile = new Profile()
                {
                    Name = nameTextBox.Text,
                    File = diag.FileName,
                    Gender = (boyRadioButton.Checked ? Gender.Boy : Gender.Girl),
                    Greeting = greetingCheckBox.Checked,
                    Picture = (pictureCheckBox.Checked ? pictureTextBox.Text : null)
                };

                SaveProfile();

                DialogResult = DialogResult.OK;
                Close();
            }
        }

        private void nameTextBox_Validating(object sender, CancelEventArgs e)
        {
            if (String.IsNullOrEmpty(nameTextBox.Text))
            {
                e.Cancel = true;
                errorProvider.SetError(nameTextBox, "Name cannot be left blank.");
            }
            else
            {
                errorProvider.SetError(nameTextBox, null);
            }
        }

        private void pictureTextBox_Validating(object sender, CancelEventArgs e)
        {
            if (pictureTextBox.Enabled)
            {
                if (String.IsNullOrWhiteSpace(pictureTextBox.Text))
                {
                    e.Cancel = true;
                    errorProvider.SetError(pictureTextBox, "Path to image file cannot be left blank.");
                    return;
                }
                else if (!(new FileInfo(pictureTextBox.Text)).Exists)
                {
                    e.Cancel = true;
                    errorProvider.SetError(pictureTextBox, "Specified file does not exist.");
                    return;
                }
            }

            errorProvider.SetError(pictureTextBox, null);
        }
    }
}
